@@ -5,9 +5,13 @@ from .cdq_learning import SoftCDQLearning
 from .daml import DPGAwareModelLearning
 from .isfv_iteration import ISFittedVIteration
 from .isfv_iteration import ISSoftVIteration
+from .mage import MAGE
+from .mapo import DAPO
+from .mapo import MAPO
 from .maximum_entropy import MaximumEntropyDual
 from .mle import MaximumLikelihood
 from .mle import ModelEnsembleMLE
+from .paml import SPAML
 from .policy_gradient import DeterministicPolicyGradient
 from .policy_gradient import ModelAwareDPG
 from .policy_gradient import ReparameterizedSoftPG
@@ -23,9 +27,13 @@ __all__ = [
     "ISFittedVIteration",
     "ISSoftVIteration",
     "MaximumEntropyDual",
+    "MAGE",
+    "DAPO",
+    "MAPO",
     "MaximumLikelihood",
     "ModelAwareDPG",
     "ModelEnsembleMLE",
+    "PAML",
     "OneStepSVG",
     "OneStepSoftSVG",
     "ReparameterizedSoftPG",
